@@ -29,6 +29,7 @@ Approach:
 
 from __future__ import with_statement, print_function
 
+import codecs
 import hashlib
 import os.path
 try:
@@ -36,19 +37,14 @@ try:
     from urllib.parse import urlparse
     from urllib.error import URLError, HTTPError
 except ImportError:
-    from urllib2 import ProxyHandler, build_opener, urlopen
+    from urllib2 import ProxyHandler, build_opener, urlopen, URLError, HTTPError
     from urlparse import urlparse
-    from urllib2 import URLError, HTTPError
 import re
 import sys
-if sys.version_info[0] >= 3:
-    basestring = str
-    unicode = str    
 
 from debian.changelog import Changelog, Version
 import debian.deb822
 import debian.debian_support
-import codecs
 import httplib2
 
 from ubuntutools.config import UDTConfig
@@ -57,6 +53,10 @@ from ubuntutools.lp.lpapicache import (Launchpad, Distribution,
 from ubuntutools.logger import Logger
 from ubuntutools import subprocess
 
+if sys.version_info[0] >= 3:
+    basestring = str
+    unicode = str
+
 
 class DownloadError(Exception):
     "Unable to pull a source package"
@@ -116,8 +116,7 @@ class Dsc(debian.deb822.Dsc):
                 if name not in their_checksums:
                     # file only in one dsc
                     continue
-                if (size != their_checksums[name][0] or
-                    checksum != their_checksums[name][1]):
+                if size != their_checksums[name][0] or checksum != their_checksums[name][1]:
                     return False
             return True  # one checksum is good enough
         return True
@@ -176,12 +175,11 @@ class SourcePackage(object):
                     Launchpad.login_existing(self._lp)
                 else:
                     Launchpad.login_anonymously()
-            spph = (Distribution(self.distribution).getArchive()
-                          .getPublishedSources(
-                              source_name=self.source,
-                              version=self.version.full_version,
-                              exact_match=True,
-                          ))
+            spph = Distribution(self.distribution).getArchive().getPublishedSources(
+                source_name=self.source,
+                version=self.version.full_version,
+                exact_match=True,
+            )
             self._spph = SourcePackagePublishingHistory(spph[0])
         return self._spph
 
@@ -238,7 +236,7 @@ class SourcePackage(object):
                 yield self._mirror_url(mirror, name)
         yield self._lp_url(name)
 
-    def pull_dsc(self):
+    def pull_dsc(self, verify_signature=True):
         "Retrieve dscfile and parse"
         if self._dsc_source:
             parsed = urlparse(self._dsc_source)
@@ -250,7 +248,7 @@ class SourcePackage(object):
             url = self._lp_url(self.dsc_name)
         self._download_dsc(url)
 
-        self._check_dsc()
+        self._check_dsc(verify_signature=verify_signature)
 
     def _download_dsc(self, url):
         "Download specified dscfile and parse"
@@ -305,10 +303,10 @@ class SourcePackage(object):
         else:
             Logger.info(message)
 
-    def _write_dsc(self):
+    def _write_dsc(self, verify_signature=True):
         "Write dsc file to workdir"
         if self._dsc is None:
-            self.pull_dsc()
+            self.pull_dsc(verify_signature=verify_signature)
         with open(self.dsc_pathname, 'wb') as f:
             f.write(self.dsc.raw_text)
 
@@ -344,7 +342,7 @@ class SourcePackage(object):
                     if block == b'':
                         break
                     downloaded += len(block)
-                    out.write(block)                    
+                    out.write(block)
                     if not self.quiet:
                         percent = downloaded * 100 // size
                         bar = '=' * int(round(downloaded * bar_width / size))
@@ -361,9 +359,9 @@ class SourcePackage(object):
             return False
         return True
 
-    def pull(self):
+    def pull(self, verify_signature=True):
         "Pull into workdir"
-        self._write_dsc()
+        self._write_dsc(verify_signature=verify_signature)
         for entry in self.dsc['Files']:
             name = entry['name']
             for url in self._source_urls(name):
@@ -473,10 +471,10 @@ class DebianSourcePackage(SourcePackage):
         if self.snapshot_list:
             yield self._snapshot_url(name)
 
-    def pull_dsc(self):
+    def pull_dsc(self, verify_signature=True):
         "Retrieve dscfile and parse"
         try:
-            super(DebianSourcePackage, self).pull_dsc()
+            super(DebianSourcePackage, self).pull_dsc(verify_signature)
             return
         except DownloadError:
             pass
@@ -491,7 +489,7 @@ class DebianSourcePackage(SourcePackage):
             break
         else:
             raise DownloadError('dsc could not be found anywhere')
-        self._check_dsc(verify_signature=True)
+        self._check_dsc(verify_signature=verify_signature)
 
     # Local methods:
     @property
@@ -510,9 +508,8 @@ class DebianSourcePackage(SourcePackage):
 
             try:
                 data = self.url_opener.open(
-                    'http://snapshot.debian.org'
-                    '/mr/package/%s/%s/srcfiles?fileinfo=1'
-                        % (self.source, self.version.full_version))
+                    'http://snapshot.debian.org/mr/package/%s/%s/srcfiles?fileinfo=1' %
+                    (self.source, self.version.full_version))
                 reader = codecs.getreader('utf-8')
                 srcfiles = json.load(reader(data))
 
@@ -543,7 +540,7 @@ class UbuntuCloudArchiveSourcePackage(UbuntuSourcePackage):
     def __init__(self, uca_release, *args, **kwargs):
         super(UbuntuCloudArchiveSourcePackage, self).__init__(*args, **kwargs)
         self._uca_release = uca_release
-        self.masters = [ "http://ubuntu-cloud.archive.canonical.com/ubuntu/" ]
+        self.masters = ["http://ubuntu-cloud.archive.canonical.com/ubuntu/"]
 
     def _lp_url(self, filename):
         "Build a source package URL on Launchpad"
@@ -639,7 +636,7 @@ def rmadison(url, package, suite=None, arch=None):
 
     # pylint bug: http://www.logilab.org/ticket/46273
     # pylint: disable=E1103
-    for line in output.strip().splitlines():
+    for line in output.decode().strip().splitlines():
         # pylint: enable=E1103
         pkg, ver, dist, archs = [x.strip() for x in line.split('|')]
         comp = 'main'
@@ -653,23 +650,23 @@ def rmadison(url, package, suite=None, arch=None):
         #
         # some versions (2.14.1ubuntu0.1) of rmadison return 'sid' when
         # asked about 'unstable'.  Others return 'unstable'.  Accept either.
-        if (suite and dist != suite and not 
+        if (suite and dist != suite and not
                 (suite == 'sid' and dist == 'unstable')):
             continue
 
         if 'source' in archs:
             yield {
-                   'source': pkg,
-                   'version': ver,
-                   'suite': dist,
-                   'component': comp,
-                  }
+                'source': pkg,
+                'version': ver,
+                'suite': dist,
+                'component': comp,
+            }
         archs.discard('source')
         if archs:
             yield {
-                   'binary': pkg,
-                   'version': ver,
-                   'suite': dist,
-                   'component': comp,
-                   'architectures': archs,
-                  }
+                'binary': pkg,
+                'version': ver,
+                'suite': dist,
+                'component': comp,
+                'architectures': archs,
+            }
